/*
 * OfficeFloor - http://www.officefloor.net
 * Copyright (C) 2005-2012 Daniel Sagenschneider
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.officefloor.frame.impl.execute.administrator;

import net.officefloor.frame.internal.structure.AdministratorContext;
import net.officefloor.frame.internal.structure.ContainerContext;
import net.officefloor.frame.internal.structure.GovernanceContainer;
import net.officefloor.frame.internal.structure.ThreadState;
import net.officefloor.frame.spi.administration.GovernanceManager;
import net.officefloor.frame.spi.governance.Governance;

/**
 * {@link GovernanceManager} implementation.
 * 
 * @author Daniel Sagenschneider
 */
public class GovernanceManagerImpl implements GovernanceManager {

	/**
	 * {@link AdministratorContext}.
	 */
	private final AdministratorContext adminContext;

	/**
	 * Index of {@link Governance} within the {@link ThreadState}.
	 */
	private final int governanceIndex;

	/**
	 * {@link ContainerContext}.
	 */
	private final ContainerContext containerContext;

	/**
	 * Initiate.
	 * 
	 * @param adminContext
	 *            {@link AdministratorContext}. {@link GovernanceContainer}.
	 * @param governanceIndex
	 *            Index of {@link Governance} within the {@link ThreadState}.
	 * @param containerContext
	 *            {@link ContainerContext}.
	 */
	public GovernanceManagerImpl(AdministratorContext adminContext,
			int governanceIndex, ContainerContext containerContext) {
		this.adminContext = adminContext;
		this.governanceIndex = governanceIndex;
		this.containerContext = containerContext;
	}

	/*
	 * ===================== GovernanceManager =====================
	 */

	@Override
	public void activateGovernance() {
		this.getGovernanceContainer().activateGovernance(this.containerContext);
	}

	@Override
	public void enforceGovernance() {
		this.getGovernanceContainer().enforceGovernance(this.containerContext);
	}

	@Override
	public void disregardGovernance() {
		this.getGovernanceContainer()
				.disregardGovernance(this.containerContext);
	}

	/**
	 * Obtains the {@link GovernanceContainer}.
	 * 
	 * @return {@link GovernanceContainer}.
	 */
	private GovernanceContainer<?, ?> getGovernanceContainer() {

		// Obtain the governance container
		GovernanceContainer<?, ?> container = this.adminContext
				.getThreadState().getGovernanceContainer(this.governanceIndex);

		// Return the governance container
		return container;
	}
}